package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````&!<``#0```"(D0````(`!30`(``)
M`"@`&P`:``$``'!$B@``1(H``$2*```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``$P``
M`!,````$`````0````$```````````````````!0B@``4(H```4`````$```
M`0```,"-``#`G0``P)T``(@"``"<`@``!@`````0```"````R(T``,B=``#(
MG0``"`$```@!```&````!`````0```!H`0``:`$``&@!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DP(T`
M`,"=``#`G0``0`(``$`"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,P``
M!````!0````#````1TY5`'!?LV$">[Q_V6HQJ,-A]&2/*Y:M!````!`````!
M````1TY5```````#`````@`````````1````2@````@````(`````9`0!"5`
M!(`H@``%H(90A(`!```+*`2,.(`208H```A*````2P```$X```!2````4P``
M`%L```!<````70````````!?````8````&$```!B````8P```&8`````````
M``````&O-.ANQ=\?SMY'+6M_FGPNQ9NVU&34?'94/)0A_^0.V7%8'.)'Q@&R
M`8MOK$OCP$+ZUX?"Y3\L6.^7>;KCDGS[H6Q@:PE#UF>OS&9"1=7LB0=PTS-B
MV^T5C"7,#3J7"W^IG)O@IP(*:AJ>4+_:5QNCX/M)````````````````````
M``````"`$0````````,`"P```````*`````````#`!8`$P(`````````````
M$@```/L``````````````!(```#.`@`````````````2````F0(`````````
M````$@```(L"`````````````!(```"6```````````````2````=`$`````
M````````$@```!$!`````````````!(````!```````````````@````A`(`
M````````````$@```$(!`````````````!(````R`0`````````````2````
MD@(`````````````$@```"0!`````````````!(```#<`0`````````````2
M````$```````````````(````)(!`````````````!(```"A`@``````````
M```2``````$`````````````$@````<"`````````````!(```"H`@``````
M```````2````+```````````````(````$X"`````````````!(```!&````
M```````````2````8P``````````````%@```&0!`````````````!(```!V
M```````````````2````TP``````````````$@```(<``````````````!(`
M``#Z`0`````````````2````Y`$`````````````$@```*\"````````````
M`!(```"R`P`````````````2````MP``````````````$@```-X"````````
M`````!$```#5`0`````````````2````^`(`````````````$0````P"````
M`````````!(```!6`0`````````````2````S`$`````````````$@```.0`
M`````````````!(```#%`0`````````````2````!0$`````````````$@``
M`+,!`````````````!(```"+`0`````````````2````G0$`````````````
M$@```#\"`````````````!(```#S`0`````````````2`````0(`````````
M````$@```$T"`````````````!(```#K`0`````````````2````Y@(`````
M````````$@```*(``````````````!(````9`@`````````````2````?P$`
M````````````$@```"`"`````````````!(```#<`@`````````````1````
M9P(`````````````$0```,8``````````````!$```"[`0`````````````2
M````,0(`````````````$@```-0"`````````````!(```!+`0``````````
M```2````*0(`````````````$@```%0``````````````!(```!5`@``````
M```````2````;@(`````````````$@```+8"`````````````!(```"N`0``
M```````````2````O0(`````````````$@```'4"`````````````"(````-
M!```7*`````````0`!<`NP,``(PW```T`0``$@`-`#($``#@+0``R`8``!(`
M#0!B`@``<!0``*@"```2``T`,@,``%0B```$````$@`-`%`#``"H-```Y`(`
M`!(`#0#C`P``2*`````````0`!<`6`0``%@B``"``@``$@`-`!@$``!(H```
M`````!``%P!#`P``V"0``"0````2``T`9@,``,PK``"4````$@`-`,<#``!T
M2```!````!$`#P#Q`P``T$4``!@!```2``T`_`,``/@@``!<````$@`-``0$
M``!<H````````!``%P`M!```7*`````````0`!<`1@0``'@L``!H`0``$@`-
M`-8#````H````````!``%@"*`P``_"0``)@!```2``T`/P0``$B@````````
M$``6`&4$``!$H```!````!$`%@#<`P``&!<````````2``T`)`0``$1%``",
M````$@`-`-@#````H````````"``%@"@`P``8"P``!@````2``T`=`,``%0A
M`````0``$@`-`)8#``#H1@``7`$``!(`#0`,!```7*`````````0`!<`;P0`
M`)0F```X!0``$@`-``!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)4
M34-L;VYE5&%B;&4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y
M<U]T97)M`%!E<FQ?<WES7VEN:70S`%!,7V-U<G)E;G1?8V]N=&5X=`!097)L
M7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?
M8W)O86M?;F]C;VYT97AT`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!0
M97)L7VYE=UA37V9L86=S`%!E<FQ?8W)O86M?;65M;W)Y7W=R87``<&5R;%]F
M<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E
M='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?
M9&5S=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E
M<WES;6%L;&]C`'!E<FQ?86QL;V,`7U]S=&%C:U]C:&M?9F%I;`!E>&ET`&QS
M965K-C0`<F5A9&1I<C8T`'-T<F1U<`!C;&]S961I<@!O<&5N-C0`<W1R<F-H
M<@!U;FQI;FL`;65M;6]V90!S=')T;VL`<W1R;&5N`')M9&ER`')E860`<W1R
M<W1R`&UK9&ER`&=E='!I9`!R96%D;&EN:P!R96%L;&]C`%]?<W!R:6YT9E]C
M:&L`7U]F<')I;G1F7V-H:P!L<W1A=#8T`%]?;&EB8U]S=&%R=%]M86EN`'-T
M9&5R<@!M96UC:'(`7U]C>&%?9FEN86QI>F4`<W1R8VAR`&UE;6-M<`!M96US
M970`;W!E;F1I<@!G971U:60`86-C97-S`&UE;6-P>0!S=')C;7``7U]E<G)N
M;U]L;V-A=&EO;@!A8F]R=`!S=')N8VUP`%]?96YV:7)O;@!?7W)E9VES=&5R
M7V%T9F]R:P!?7W-T86-K7V-H:U]G=6%R9`!L:6)P97)L+G-O+C4N,S8`;&EB
M8RYS;RXV`&QD+6QI;G5X+G-O+C,`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S
M96YA;64`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R
M7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`'-H85]F:6YA;`!G971?
M=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?24]?<W1D:6Y?
M=7-E9`!?7V1A=&%?<W1A<G0`7U]B<W-?<W1A<G1?7P!S:&%?=7!D871E`'AS
M7VEN:70`7U]E;F1?7P!?7V)S<U]E;F1?7P!?7V)S<U]S=&%R=`!S:&%?:6YI
M=`!?96YD`'!A<E]M:W1M<&1I<@!?961A=&$`<&%R7W-E='5P7VQI8G!A=&@`
M<&%R7V9I;F1P<F]G`&UY7W!A<E]P;`!P87)?:6YI=%]E;G8`1TQ)0D-?,BXT
M`$=,24)#7S(N,S0`1TQ)0D-?,BXS,P`````````"``$``@`"``(``0`!``$`
M`0`"``$``0`"``$``@`!``$``@`"``(``@`!``,``0`!``$``0`!``$``@`"
M``(``@`!``(``@`$``(``0`"``$``@`!``(``@`"``(``@`"``,``@`"``$`
M`@`!``(``@`"``$``@`"``(``0`"``$`!0`"``(``@`"``(``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!`````0`!`"0#```0````(````!1I:0T```0`?`0````````!``,`&@,`
M`!``````````M)&6!@``!0"&!```$````+.1E@8```,`D00``!`````4:6D-
M```"`'P$````````P)T``!<```#$G0``%P```/R?```7````!*```!<````4
MH```%P```!B@```7````(*```!<````DH```%P```"B@```7````+*```!<`
M```PH```%P```#B@```7````/*```!<```!$H```%P```,R?```5"@``T)\`
M`!4+``#4GP``%1(``-B?```5&```W)\``!,;``#@GP``%1P``.2?```5'0``
MZ)\``!4E``#LGP``%2<``/"?```5/```])\``!4]``#XGP``%4D``-R>```6
M`P``X)X``!8$``#DG@``%@4``.B>```6!@``[)X``!8'``#PG@``%@@``/2>
M```6"0``^)X``!8+``#\G@``%@P```"?```6#0``!)\``!8.```(GP``%@\`
M``R?```6$```$)\``!81```4GP``%A,``!B?```6%```')\``!85```@GP``
M%A8``"2?```6%P``*)\``!89```LGP``%AH``#"?```6'@``-)\``!8?```X
MGP``%B```#R?```6(0``0)\``!8B``!$GP``%B,``$B?```6)```3)\``!8F
M``!0GP``%B@``%2?```6*0``6)\``!8J``!<GP``%BL``&"?```6+```9)\`
M`!8M``!HGP``%BX``&R?```6+P``<)\``!8P``!TGP``%C$``'B?```6,@``
M?)\``!8S``"`GP``%C0``(2?```6-0``B)\``!8V``",GP``%C<``)"?```6
M.```E)\``!8Y``"8GP``%CH``)R?```6/@``H)\``!8_``"DGP``%D```*B?
M```600``K)\``!9"``"PGP``%D,``+2?```61```N)\``!9%``"\GP``%D8`
M`,"?```61P``Q)\``!9(``#(GP``%DD```A`+>ET`0#K"("]Z`3@+>4$X)_E
M#N"/X`CPON4TC0```,:/X@C*C.(T_;SE`,:/X@C*C.(L_;SE`,:/X@C*C.(D
M_;SE`,:/X@C*C.(<_;SE`,:/X@C*C.(4_;SE`,:/X@C*C.(,_;SE`,:/X@C*
MC.($_;SE`,:/X@C*C.+\_+SE`,:/X@C*C.+T_+SE`,:/X@C*C.+L_+SE`,:/
MX@C*C.+D_+SE`,:/X@C*C.+<_+SE`,:/X@C*C.+4_+SE`,:/X@C*C.+,_+SE
M`,:/X@C*C.+$_+SE`,:/X@C*C.*\_+SE`,:/X@C*C.*T_+SE`,:/X@C*C.*L
M_+SE`,:/X@C*C.*D_+SE`,:/X@C*C.*<_+SE`,:/X@C*C.*4_+SE`,:/X@C*
MC.*,_+SE`,:/X@C*C.*$_+SE`,:/X@C*C.)\_+SE`,:/X@C*C.)T_+SE`,:/
MX@C*C.)L_+SE`,:/X@C*C.)D_+SE`,:/X@C*C.)<_+SE`,:/X@C*C.)4_+SE
M`,:/X@C*C.),_+SE`,:/X@C*C.)$_+SE`,:/X@C*C.(\_+SE`,:/X@C*C.(T
M_+SE`,:/X@C*C.(L_+SE`,:/X@C*C.(D_+SE`,:/X@C*C.(<_+SE`,:/X@C*
MC.(4_+SE`,:/X@C*C.(,_+SE`,:/X@C*C.($_+SE`,:/X@C*C.+\^[SE`,:/
MX@C*C.+T^[SE`,:/X@C*C.+L^[SE`,:/X@C*C.+D^[SE`,:/X@C*C.+<^[SE
M`,:/X@C*C.+4^[SE`,:/X@C*C.+,^[SE`,:/X@C*C.+$^[SE`,:/X@C*C.*\
M^[SE`,:/X@C*C.*T^[SE`,:/X@C*C.*L^[SE`,:/X@C*C.*D^[SE`,:/X@C*
MC.*<^[SE`,:/X@C*C.*4^[SE`,:/X@C*C.*,^[SE`,:/X@C*C.*$^[SE`,:/
MX@C*C.)\^[SE`,:/X@C*C.)T^[SE`,:/X@C*C.)L^[SE`,:/X@C*C.)D^[SE
M`,:/X@C*C.)<^[SE4,*?Y5`RG^5P0"WI#,"/X"C03>(<`(WE&!"-Y10@C>4#
M,)SG'`"-XA@0C>(4((WB*$*?Y0`PD^4D,(WE`#"@X]G__^L8(I_E!$"/X!0R
MG^4"()3G#""-Y0,PE.<"$*#A`P"@X1`PC>7>#`#K^#&?Y0,PE.<`0-/E``!4
MXU$```KH,9_EU0P`ZP,PG^<<0)WE`R"0YP0`A.+&,]+E!P%PXP,P@^,#0(3B
MQC/"Y6,``(H``:#AI___Z[0AG^6TP9_E&!"=Y0(@C^``()+E#,"/X!Q0G>4!
M`%7C`#"@X00`C.4``)'E"""#Y8PAG^4``(/E`B"/X`P@@^6`(9_E`B"/X`0@
M@^5.``#:!`!!X@S`@^(%`8#@!."QY03@K.4!`%#A^___&@,0A>(``*#C4%&?
MY0``C>4!`8/G2!&?Y050C^`$(*#A#`"5Y0$0C^`)___K`$!0XB@```HL49_E
M(&"-X@50C^`,`)7E2O__ZQP!G^4&$*#A``"/X*0``.L``%#C(0``"@@QG^4#
M,(_@#`"3Y>G^_^LA___K^""?Y;@PG^4"((_@`S"2YP`@D^4D,)WE`B`SX``P
MH.,E```:!`"@X2C0C>)P@+WH`O__Z\@@G^4"((_@``!0XPP`@N4:```*%/__
MZ[0PG^5\#`#K`S"?YP,PD.=[1\/EH/__Z@P`E>7E_O_K`$"@X=+__^H(`)7E
M``!0XP$```H_"`#KV/__ZGP`G^4&$*#A``"/X'<``.L``%#C"`"%Y='__PKU
M___J&O__ZP00H..V___J`0"@XV'__^LD___K3(H``!P!```0B@``_````!0!
M```D`0``W(H```B+```(BP``G#8``(PV``"8B@``E`H``'2*``#@,P``3(H`
M`+B(```$B@``>(D``,@R````L*#C`."@XP00G>0-(*#A!"`MY00`+>4<H)_E
M&#"/X@.@BN``,*#C!#`MY0P`G^4``)KG-?__ZYC^_^M\AP``+`$``!0PG^44
M()_E`S"/X`(@D^<``%+C'O\O`9[^_^IDAP````$``"P`G^4L,)_E``"/X`,P
MC^```%/A(#"?Y0,PC^`>_R\!&""?Y0(PD^<``%/C'O\O`1/_+^&XB```M(@`
M`#"'```$`0``.`"?Y3@PG^4``(_@`S"/X``P0^"C'Z#A0Q&!X"0PG^7!$+#A
M`S"/X![_+P$8()_E`C"3YP``4^,>_R\!$_\OX72(``!PB```X(8```@!``!,
M,)_E3""?Y0,PC^``,-/E`B"/X```4^,>_R\1.#"?Y1!`+>D#,)+G``!3XP(`
M``HH,)_E`P"?YP3__^O*___K'#"?Y0$@H.,#,(_@`"##Y1"`O>@DB```I(8`
M`"@!``"TAP``Y(<``-#__^K,,)_E\$<MZ0"`4.(#,(_@*P``"KP@G^4",)/G
M`)"3Y0``6>,H```*`%#8Y0%PH.$``%7C/0!5$P%0H!,`4*`#$0``&@!`F>4`
M`%3C#```"@E@H.$$`*#A!2"@X0@0H.'$_O_K``!0XP(``!H%,-3G/0!3XPL`
M``H$0+;E``!4X_/__QH$`*#A\(>]Z`A0H.$!,/7E``!3XST`4Q/[__\:"%!%
MX.;__^H)8$;@`5"%XD9AH.$%0(3@!`"@X0!@A^7PA[WH"$"@X>W__^H)0*#A
MZ___ZCR&```8`0``D""?Y9`PG^4"((_@$$`MZ7#03>(#,)+G#1"@X0!`H.$`
M,)/E;#"-Y0`PH.-__O_K``!0XP``H!,$```:$#"=Y0\Z`^(*"E/C`0E3$PH`
M``I(()_E0#"?Y0(@C^`#,)+G`""3Y6PPG>4"(#/@`#"@XP<``!IPT(WB$("]
MZ`(0H.,$`*#A)/[_ZQ`/;^&@`J#A[O__ZEG^_^MDA0``'`$``!2%``!@(9_E
M8#&?Y0(@C^#P0"WI`S"2YWS03>(`8%#B`#"3Y70PC>4`,*#C`@``"@`PUN4`
M`%/C"@``&C`AG^4H,9_E`B"/X`,PDN<`()/E=#"=Y0(@,^``,*#C00``&GS0
MC>+P@+WHUOW_ZP!`4.+Q__\*!`"@X5G^_^L``%#C*@``"A,PT.434(#B+@!3
MXP(``!H!,-7E``!3X_3__PH3,-#E+@!3XR4```H&`*#A`/[_ZP!PH.$%`*#A
M_?W_ZP``A^`"`(#B(?[_ZZ0PG^4`(.#C`S"/X`$0H.,$4(WE`&"-Y0!PH.%`
M_O_K"!"-X@<`H.'C_?_K`0!PXP<`H.$#```*&#"=Y0\Z`^(!"5/C$@``"NK]
M_^L'`*#AT/W_ZP0`H.$N_O_K``!0X]3__QH$`*#A]_W_ZP8`H.$0_O_KO?__
MZ@$PU>4N`%/CUO__&@(PU>4``%/CQ?__"M+__^JG___KZ___ZOS]_^O`A```
M'`$``(B$```P+@``\$\MZ0'83>(<T$WB`A"@XTC!G^4`$(WE1!&?Y0S`C^`!
M$)SG`>B-X@`@H.,`,*#C`!"1Y100CN4`$*#C%.".X@"0H.'@_?_K`6!0X@"`
MP>+(+Z#AR#\FX`(P4^`#.*#A(SB@X0(P(^`",%/@`B#"X`-@5N`"@,C@``!8
MXS,``+K@<)_EX*"?Y>"PG^4'<(_@#%"-X@`0H.,(,*#A!B"@X0D`H.$`$(WE
MQ_W_ZPH@H.$%$*#A"0"@X8W]_^L'`%#C'0``F@@`0.(`0)7@`P``.AD``.H!
M0$3B!0!4X18``#H((*#C!Q"@X00`H.%9_?_K``!0X_;__QH%0$3@!@"4X,0?
MJ.!H()_E5#"?Y0(@C^`!R(WB`S"2YQ3`C.(`()/E`#"<Y0(@,^``,*#C"@``
M&@'8C>(<T(WB\(^]Z`%H5N(`@,CB`0!XXPL`5@'0__\:``#@XP`0H.'I___J
MH/W_ZS2#```<`0``_(,```@``0```/__1((``/!!+>D!<*#A`!&?Y0`QG^4!
MVDWB"-!-X@$0C^`#,)'G`&"@X0$*C>($`(#B`#"3Y0`P@.4`,*#CV`"?Y02`
MC>+4()_E``"/X`@0H.&D_?_K`$!0X@<``-H(4(WB`3!$X@/`A>`$(%SE``!2
MXQ<``!H``%/C%```&J`PG^6W"@#K`S"?YP<@H.$#`)#G!A"@X2K]_^N(()_E
M=#"?Y0(@C^`!&HWB`S"2YP00@>(`()/E`#"1Y0(@,^``,*#C$@``&@':C>((
MT(WB\(&]Z`-`H.$$(*#A+Q"@XP@`H.&8_?_K``!0X^/__PHX,)_EFPH`ZP,P
MG^<((*#A`P"0YP80H.$$,*#A.OW_Z^'__^I6_?_KP($``!P!``#4*P``_P\`
M`&2"```\@0``]($``/!'+>D`,-'E$"*?Y3T`4^,,,I_E`B"/X`%`H.$#,)+G
M`4"!`@C03>(`4*#A!`"@X0`PD^4$,(WE`#"@XQ7]_^L-$*#AW(&?Y0B`C^``
M8*#A!0"@X8+^_^L`D%#B0```"@S]_^L``%;A-P``FK@QG^4`<)WE`X"8YP=Q
MH.$`,-7E``!3XST`4Q,!,*`3`#"@`P4```H%,*#A`2#SY0``4N,]`%(3^___
M&@4P0^`"`(;B`P"`X`!@F.4=_?_K``!0XP<`AN<5```*`""8Y04`H.$!,-#D
M!Q"2YP``4^,]`%,3`##!Y08```H!(('B`3#0Y`(0H.$]`%/C``!3$P$PPN3Y
M__\:/3"@XP$@H.$`,,'E`3#4Y`$PXN4``%/C^___&@@AG^7X,)_E`B"/X`,P
MDN<`()/E!#"=Y0(@,^``,*#C-0``&@C0C>+PA[WH`9!)X@$PU.0!,.GE``!3
MX_O__QKN___JP#"?Y0.`F.<`<)CE`#"7Y0``4^,D```*!S"@X00@L^4)$*#A
M``!2XP&0B>+Z__\:`Q"!X@$1H.&0,)_E`S"/X``@D^4``%+C#P``&@$@H.,!
M`*#A`""#Y=S\_^L`H%#BU?__"@<0H.$)<:#A!R"@X>C\_^L`H(CE`#"@XP"0
MC>4!D(GB"3&*YZ+__^H'`*#A_OS_ZP``4.,`H*#A``"(Y<7__PH)<:#A\O__
MZ@.0H.$($*#CW___ZL?\_^N8@```'`$``&2````8`0``A'\``(B```!X$)_E
M>#"?Y3!`+>GZ"0#K`1"/X&Q0G^44T$WB`S"1YPPPC>4%4)_G7#"?Y5P0G^4,
M()WE`$"@X0,PC^`%`)#G`1"/X-G\_^M$()_E1#"?Y0(@G^=`$)_E`@"4YSP@
MG^4#,(_@`,"@XP(@C^`!$(_@"!"-Z'/\_^L4T(WB,("]Z&1^```0`0``7'\`
M``QI``"$*```,'\``$`K``!T*```Y!,``!!`+>G3"0#K.$"?Y3@@G^4$0(_@
M-#"?Y0C03>("()3G!""-Y0,PG^<D$)_E`P"0YR`PG^4!$(_@`S"/X`C0C>(0
M0+WHL/S_ZL!]```0`0``N'X``.PG``!H:```X""?Y7!`+>G<,)_E`MI-XAC0
M3>("((_@`S"2YP(:C>(4$('B`#"3Y0`P@>4`,*#CC/S_Z[00G^6T,)_E#$"-
MX@$0C^`!:HWBJ""?Y0,PC^`08(;B`P"-Z`$0H.,$`*#AC/S_ZP0`H.$!*J#C
M!A"@X8+\_^L`0%#B&```N@$`A.)=_/_K`%!0XA0```H$(*#A!A"@X3?\_^L`
M,*#C!##%YU0@G^5`,)_E`B"/X`(:C>(#,)+G%!"!X@`@D^4`,)'E`B`SX``P
MH.,#```:!0"@X0+:C>(8T(WB<("]Z$G\_^L`4*#C[?__ZF!]```<`0``Q"<`
M`*PG```!$```S'P``+[__^I((I_E\$\MZ40RG^5"W4WB!-!-X@(@C^``8*#A
M-`*?Y0,PDN=!S8WB$("-X@%`H.$``(_@"!"@X3S`C.(`,)/E`#",Y0`PH.-V
M_?_K+Q"@XP!0H.$&`*#ATOO_ZP``4.,2```*\`&?Y080H.$``(_@T_[_ZP8`
MH.'@(9_ET#&?Y0(@C^!!'8WB`S"2YSP0@>(`()/E`#"1Y0(@,^``,*#C:0``
M&D+=C>($T(WB\(^]Z`0`H.$&_/_KI!&?Y0$0C^`5_/_K`$!0XN7__PH`,-3E
MD)&?Y8"@C>(``%/C"9"/X`1P2N([```*``!5XP0```H$$*#A!0"@X3K\_^L`
M`%#C*P``"@0`H.'3^__K`3!`X@,PA.`#`%3A`+"@X0`PA#``$*`S`0"$,@,`
M`#H(``#J`P!0X0`0P^4"```*`2!SY2\`4N/Y__\*!`"@X<+[_^L`L*#A!@"@
MX;_[_^L+`(#@`0"`X@$*4..]__\J^`"?Y0DPH.$``(_@`2J@XP$0H.-!`(WI
M`$"-Y0<`H.$`_/_K"!"@X0<`H.&C^__K``!0XP,``!I@,!KE#SH#X@()4^,5
M```*M!"?Y0``H.,!$(_@U?O_ZP!`4.*E__\*`##4Y0``4^/#__\:``!5XQ8`
M``H`,-7E+@!3XP,```J`0)_E`;"@XP1`C^#5___J`3#5Y0``4^/J__\*]___
MZ@$0H.,'`*#A@?O_ZP``4./D__\:4`"?Y0<0H.$``(_@9/[_ZP<`H.&F^__K
MCO__ZCA`G^4!L*#C!$"/X,'__^JL^__K7'P``!P!``#8)@``J"8``/![``!H
M)@``3"8``+PE``!H)0``$"4``.PD``#`)```$$`MZ2\0H.,`0*#A5/O_ZP``
M4.,!0(`2!`"@X1!`O>B+^__J="&?Y7!`+>EP,9_E`=I-X@(@C^`(T$WB`1J-
MX@,PDN<`8%#B!!"!X@`PD^4`,('E`#"@XR\```H`,-;E``!3XRP```I;^__K
M`2"`X@$*4N,`0*#A.```B@10C>(&$*#A!0"@X5G[_^L!,$3B`S"%X`4`4^$'
M``":`!"@XP(``.H%`%/A`1##Y0(```H!(%/D+P!2X_G__PHO$*#C!0"@X2;[
M_^L``%#C)0``"@4`4.$`,*"#`##`A04`H.%;^__KO""?Y;0PG^4"((_@`1J-
MX@,PDN<$$('B`""3Y0`PD>4"(#/@`#"@XR(``!H!VHWB"-"-XG"`O>B(()_E
M?#"?Y0(@C^`!&HWB`S"2YP00@>(`()/E`#"1Y0(@,^``,*#C%```&F``G^4`
M`(_@`=J-X@C0C>)P0+WH//O_Z@``H./>___J1""?Y3`PG^4"((_@`1J-X@,P
MDN<$$('B`""3Y0`PD>4"(#/@`#"@XR``GP4``(\`[/__"CC[_^N\>0``'`$`
M``1Y``#,>```.",``(!X``#P(@``R"2?Y<@TG^4"((_@<$`MZ<!DG^4#,)+G
M"-!-XKA4G^4&8(_@#4"@X0`PD^4$,(WE`#"@XP50C^`$$*#A!@"@X6G\_^L`
M`%#C#@``"HPTG^4``)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P
M@^($()/E!""#Y```4N/[__\:Z___ZE1DG^4&8(_@!!"@X08`H.%3_/_K``!0
MXPX```HT-)_E``"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B
M!""3Y00@@^0``%+C^___&NO__^H`9)_E!F"/X`00H.$&`*#A/?S_ZP``4.,.
M```*W#.?Y0``G>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@
MD^4$((/D``!2X_O__QKK___JK&.?Y09@C^`$$*#A!@"@X2?\_^L``%#C#@``
M"H0SG^4``)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E
M!""#Y```4N/[__\:Z___ZEACG^4&8(_@!!"@X08`H.$1_/_K``!0XPX```HL
M,Y_E``"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@
M@^0``%+C^___&NO__^H$8Y_E!F"/X`00H.$&`*#A^_O_ZP``4.,.```*U#*?
MY0``G>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@D^4$((/D
M``!2X_O__QKK___JL&*?Y09@C^`$$*#A!@"@X>7[_^L``%#C#@``"GPRG^4`
M`)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E!""#Y```
M4N/[__\:Z___ZEQBG^4&8(_@!!"@X08`H.'/^__K``!0XPX```HD,I_E``"=
MY0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@@^0``%+C
M^___&NO__^H(8I_E!F"/X`00H.$&`*#AN?O_ZP``4.,.```*S#&?Y0``G>4#
M,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@D^4$((/D``!2X_O_
M_QKK___JM&&?Y09@C^`$$*#A!@"@X:/[_^L``%#C#@``"G0QG^4``)WE`S"5
MYP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E!""#Y```4N/[__\:
MZ___ZF!AG^4&8(_@!!"@X08`H.&-^__K``!0XPX```H<,9_E``"=Y0,PE><`
M$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@@^0``%+C^___&NO_
M_^H,`9_E!!"@X0``C^!X^__K`!!0X@(```KX`)_E``"/X-K\_^OP`)_E!!"@
MX0``C^!O^__K`!!0X@(```K<`)_E``"/X-'\_^O4`)_E!!"@X0``C^!F^__K
M`!!0XA(```K``)_E``"/X,C\_^NX()_E9#"?Y0(@C^`#,)+G`""3Y00PG>4"
M(#/@`#"@XQ```!J8$)_EF`"?Y0$0C^```(_@"-"-XG!`O>BX_/_JA`"?Y000
MH.$``(_@3?O_ZP`04.+I__\*<`"?Y0``C^"O_/_KY?__ZOWY_^LL>```'`$`
M`-@B````>```&`$``'@B```H(@``W"$``(PA``!$(0``B"```*`@``!4(```
M""```#0?``!@'P``-!\``%`?``!0'P``3!\``'`>``#(<P``*!\``(P>``#X
M'@``?!X``'P@G^5\,)_E`B"/X'@`G^4$X"WE#-!-X@,PDN<``(_@#1"@X0`P
MD^4$,(WE`#"@XQ_[_^L``%#C!0``"@``T.4``%#C,`!0$P$`H`,``*`3`0`@
MXC0@G^4H,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^``,*#C`0``&@S0C>($\)WD
MPOG_Z_1R```<`0``Z!T``*!R```00"WI>OG_ZYKY_^L``%#C``"0%1"`O>@\
M(9_E\$`MZ3@QG^4X89_E`B"/X!S03>(#,)+G!F"/X`!0H.$0$(WB!@"@X0`P
MD^44,(WE`#"@X_+Z_^L`0%#B`@``"@`PU.4``%/C#@``&O@@G^7L,)_E`B"/
MX`,PDN<`()/E%#"=Y0(@,^``,*#C,@``&M@`G^4%$*#A``"/X!S0C>+P0+WH
M1?S_Z@40H.%[^?_K``!0XPH```JT()_EH#"?Y0(@C^`#,)+G`""3Y10PG>4"
M(#/@`#"@XQ\``!H<T(WB\("]Z`4`H.%:^?_K`'"@X00`H.%7^?_K``"'X`(`
M@.)[^?_K;""?Y6PPG^4"((_@`S"/X`$0H.,(0(WE!""-Y0!0C>4`(.#C`$"@
MX9?Y_^M(()_E*#"?Y0(@C^`#,)+G`""3Y10PG>4"(#/@`#"@XP00H`$&`*`!
MS___"F?Y_^M`<@``'`$``+P=``#X<0``7!T``*QQ```4'```%!P``#1Q```X
MQI_E\$\MZ0S`C^`,,(SB`*"@X0<`D^CTT$WBB&"-X@<`AN@8)I_E&#:?Y0(@
MC^`#,)+G&'",X@`PD^7L,(WE`#"@XP\`M^B@0(WB!."@X0\`KN@#`)?H,,",
MX@,`CN@'`)SHE%"-X@<`A>C8!9_E(("-X@``C^`($*#AA_K_Z\BUG^4+L(_@
M`'!0X@(```H`,-?E``!3XQ@!`!KT^/_K%/G_ZP``4.-Z```*`'"0Y0``5^-W
M```*!P"@X03Y_^N``*#A`0"`XBCY_^L`,-?E``!3XP!0H.$<`(WE"P``"FR5
MG^4)D(_@!0"@X0`PC>4`(.#C"3"@X0$0H.-"^?_K`3#WY0)0A>(``%/C]?__
M&D`%G^4``(_@`@``Z@0`M.4``%#C#0``"@@0H.%;^O_K`%!0XOC__PH`,-7E
M``!3X_7__PJ,^O_K``!0X_+__PH%`*#A_/C_ZP!`4.(-```:!$"6Y```5.,*
M```*`##4Y0``4^/0```*!`"@X7[Z_^L``%#C]?__"@0`H.'N^/_K`$!0XO'_
M_PH$`*#AS/C_ZQQ0G>4`8*#A!0"@X<CX_^L`8(;@`6N&X@1@AN(&`*#AZOC_
MZY`TG^4`(.#C`S"/X`@PC>6$-)_E`1"@XP,PC^`$,(WE>#2?Y0Q0C>4#,(_@
M`$"-Y0!PH.$#^?_K!QV@XP<`H.%M^/_K`0!PXP,``!H8^?_K`!"0Y1$`4>.L
M```:"!"@X0<`H.'?^/_K`%!0XBT```HL))_E`#":Y0(0F^<D))_E``"1Y0(@
MC^`!$*#C`'"-Y<OX_^L`8*#C#"2?Y>`SG^4"((_@`S"2YP`@D^7L,)WE`B`S
MX``PH./N```:!@"@X?30C>+PC[WHKOC_ZP!P4.**```:!`"5Y```4.,)```*
M"!"@X?SY_^L`,%#B^/__"@`PT^4``%/C\O__&@0`E>0``%#C]?__&@T`H..F
M^/_KF'.?Y5,PH.,'<(_@`%"@X1P`C>5\___J,#"=Y0\Z`^(!"5/CS?__&CA`
MG>5;^/_K``!4X<G__QHP,)WE@SN@X:,[H.$'#5/CQ/__&@8`H.&1^/_K"!"@
MX0!@H.%``Y_E``"/X-CY_^L`$%#B?```"@``FN5*_/_K`)!0XG@```H)`*#A
M7?C_ZP,`4.,`0*#A#```F@P3G^4$`$#B``")X`$0C^"X^/_K``!0XP4``!H$
M`%3CG```"@1`B>`%,%3E+P!3XY@```K<`I_E"!"@X0``C^"\^?_K``!0XP,`
M``H`,-#E,`!3XP``4Q,$```:`!"@XPD`H.%/^/_K`$!0XED``!JD$I_EI`*?
MY0$0C^```(_@$_O_ZWKX_^N4,I_EE**?Y0,PC^`,,(WEC#*?Y8R2G^4#,(_@
M!#"-Y80RG^6$@I_E`S"/X``@X.,!$*#C`'"-Y0J@C^`)D(_@"("/X`@`C>4&
M`*#A<OC_ZPX``.J+^/_K`#"0Y1$`4^,0```:8/C_ZP%0A>(*,*#A!""@X0$0
MH.,0D(WE#%"-Y0#`H.&`$8WH!@"@X6+X_^L'':#C!@"@X<SW_^L!`'#C`$"@
MX>K__PH'`*#A]_?_Z_P!G^4&$*#A``"/X.+Z_^L&`*#A=_[_ZV?__^H#0*#A
M-/__Z@+X_^N``*#A`0"`XOS^_^J,(9_E`#":Y0(`F^?`(9_E``"0Y0(@C^`$
M$(WE`'"-Y0$0H.,B^/_K5?__ZF3^_^N@(9_E.#&?Y0(@C^`#,)+G`""3Y>PP
MG>4"(#/@`#"@XT0``!H'`*#A]-"-XO!/O>@$^/_J`)":Y83__^H4^O_K`)!1
MX@"`H.&A__^Z"B!0X@"@H.,`,,GB!`"@X;BPC>(`H(WE_??_ZP8@H.,+$*#A
M!`"@X</W_^LL,9_EN""=Y0,`4N&2__\:O"O=X1PQG^4#`%+ACO__&C(@6.(`
M,,GB!`"@X0"@C>7L]__K!`"@X<!`C>($$*#A*""@X['W_^OL,)_E`"#@XP,P
MC^`,,(WEX#"?Y0$0H.,#,(_@&`"-Z=0PG^4&`*#A`S"/X`!PC>7HH,WE`_C_
MZZ7__^H$0)KE``!4XV/__PH$`*#AK_?_ZP,`4.-?__^:H!"?Y00`0.(``(3@
M`1"/X`OX_^L``%#C!)"@`5?__^K.]__K&'(``+QP```<`0``#!L``&1P``"D
M&P``*!L``-`:``#,&0``I!H``"`!``"8&@``A&X``*09````&@``R!D``$P8
M``",&```#!@``!P:``!$&0``H!<``.@9``!$&0``>!<``-@6``"\%P``W&L`
M``!#04-(10``2!@``,P5``!@%P``'!<``'P2G^5\(I_E`1"/X'!`+>GD!`#K
M`B"1YPC03>)H,I_E`""2Y00@C>4`(*#C`S"?YPU0H.$#0)#G4`*?Y6@PU.4`
M`(_@!1"@X6DPQ.7A^/_K``!0XP(```H`,-#E,0!3XVT```I@_/_K)#*?Y<T$
M`.L#,)_G`T"0YQ@2G^4$`*#A`1"/X`,PH.,!(*#C-_?_ZP!`4.(.```*$""4
MY?@QG^4`$)+E`S"?Y_`AG^6]!`#K`B"/X`!@H.$#`)#G,??_ZQ`PE.4`$)/E
M"#"1Y0$%$^-=```:R#&?Y<@1G^4#,)_GL`0`ZP$@H.,`8*#A`1"/X`,`D.<#
M,*#C'/?_ZP!`4.(+```*H`&?Y040H.$``(_@L/C_ZP`@4.)#```*C#&?Y1`0
ME.4#,)_G`!"1Y0,`EN<4]__K>#&?Y9H$`.L#,)_G<!&?Y0-@D.<`0*#A`1"/
MX`$@H.,&`*#A]?;_ZU@AG^4"((_@`!"@X08`H.$%]__K2#&?Y4@!G^4#,)_G
M`""@XP,PE.<%$*#A``"/X&D@P^60^/_K+%&?Y050C^```%#C`$"@X0@`A>42
M```*!QV@XP0`H.'/]O_K`2"`XA$`4.,!`%(3`#"@X24``(KX()_EL#"?Y0(@
MC^`#,)+G`""3Y00PG>4"(#/@`#"@XQL``!H(T(WB<("]Z`0`E>7-_?_K``!0
MXP!`H.$(`(7EYO__&K@`G^4``(_@.O?_ZP$PT.4``%/CD___"HW__^J@,)_E
M$""4Y0,PC^`$,)/E``"2Y0`0D^5_^?_KN?__ZH0PG^4#,)_G`P"6YPSW_^N<
M___J$_?_ZW`@G^5P`)_E`B"/X`0@DN4``(_@`!"2Y00@H.$@]__K&&H``!P!
M````:P``S!0``+QJ```X%@``B&H```P6``!0:@``V!4``+@3```(:@``\&D`
M`'P5``"`%0``M&D``#`3```$:@``3&@``-04``!H:0``W&@``#!I``"8%```
M%"&?Y10QG^4"((_@,$`MZ0,PDN<,T$WB`#"3Y00PC>4`,*#C`%"@X5#[_^LO
M$*#C`$"@X9WV_^L``%#C`4"`$@0`H.'5]O_K#1"@X0!`H.',`)_E``"/X"7X
M_^L`,%#B"@``"@`PT^4P`%/C``!3$P$PH`,`,*`3`3`CX@``5>,`,*`#`3`#
M$@``4^,*```:D""?Y80PG^4"((_@`S"2YP`@D^4$,)WE`B`SX``PH.,8```:
M#-"-XC"`O>@`,-7E``!3X_'__PI<$)_E!""@XP$0C^`$`*#AX_;_ZP``4./J
M__\:1""?Y3`PG^4"((_@`S"2YP`@D^4$,)WE`B`SX``PH.,#```:!0"@X0S0
MC>(P0+WH5OC_ZJSV_^LT9P``'`$``/`1``"D9@``(!(``%!F``#P3RWI7.R?
MY5P\G^4.X(_@I]]-X@,PGN<0((WB`!"@X4#`@.*`4(#B`#"3Y90RC>4`,*#C
M`@"@X0!`H.,$8!SE"'`<Y28TH.%GZ"?@_SP#XB8\@^$NY*#A!H2@X08\@^'_
M[,[C_V@(X@C`C.)GY"[@!C"#X04`7.$`X(#E!$"`Y0@P@.4,0(#E$`"`XNK_
M_QJ"/X+B!#"-Y8@PG>48X(WB'*"=Y0@0C>5X@)WE?""=Y1BPG>6`<)WEA&"=
MY8S`G>404)WE%$"=Y0X`H.$#$*#A#."-Y0"@C>4!``#J";"@X0`PC>4!,*#A
M/."0Y3@0D.4(D+#E`*"@XPD0(>`($"'@!X"@X0-PH.$$,)#E!1`AX`/@+N`"
MX"[@!.`NX`8@H.$,8*#AH<^@X8[`C.$!$)'@#!"!X03`G>4`0)WE``!<X0M0
MH.$*P*#A=*"`Y7`0@.7A__\:"!"=Y0S@G>4`@)'E"#N?Y0$(D>D((![E($"1
MY:AMH.$0<)'E&)"1Y0,@DN"`8H;A!""2X(ABAN$,P)'E`F"6X`D@)^`K4:#A
M"R`"X`D@(N`,7X7A`F"6X`M?A>$8()WE*,&@X0#/C.$%`"?@`R"2X`@``.`)
M()+@!P`@X`C/C.$``)+@""">Y0Q`)>`#()+@!D`$X`5`).`'()+@Y@V`X`0@
MDN#@38+@$"">Y0,@DN`%()+@9E$LX`!0!>`,4"7@!2"2X!A0GN5@`:#A`U"5
MX`S`E>!F42#@!%`%X&91)>#D+8+@!<"<X.)=C.`@P)[E`\"<X&;!C.!D82#@
M`F`&X`!@)N`&P)S@*&">Y6(AH.$#8);@``"6X&1A(N`%8`;@9&$FX.7-C.`&
M`)#@[&V`X#``GN4#`)#@9`&`X&5!(N`,0`3@`D`DX`0`D.`X0)[E;,&@X0-`
ME.`"()3@94$LX`9`!.!E023@Y@V`X`0@DN#@38+@0"">Y0,@DN!E(8+@9E$L
MX`!0!>`,4"7@!2"2X$A0GN5@`:#A`U"5X`S`E>!F42#@!%`%X&91)>#D+8+@
M!<"<X.)=C.!0P)[E`\"<X&;!C.!D82#@`F`&X`!@)N`&P)S@6&">Y6(AH.$#
M8);@``"6X&1A(N`%8`;@9&$FX.7-C.`&`)#@[&V`X&``GN4#`)#@9`&`X&5!
M(N`,0`3@`D`DX`0`D.!H0)[E;,&@X0-`E.`"()3@94$LX`9`!.!E023@Y@V`
MX`0@DN#@38+@<"">Y0,@DN!E(8+@9E$LX`!0!>`,4"7@!2"2X'A0GN5@`:#A
M`U"5X`S`E>!F42#@!%`%X&91)>#D+8+@!<"<X.)=C."`P)[E`\"<X&;!C.!D
M82#@`F`&X`!@)N`&P)S@Y6V,X(C`GN5B(:#A`\"<X```G.!DP2+@!<`,X&3!
M+.`,`)#@YLV`X)``GN4#,)#@90$BX`8``.`"`"#@9#&#X``PD^#LK8/@F`">
MY2PXG^5F8:#A`P"0X*!`GN4"()#@90$FX`P`(.``()+@`P"4X&4!@.#J38+@
MJ%">Y6PA)N`*("+@`@"0X&HAH.$#4)7@L*">Y090E>!L82+@!&`FX.0-@.`&
M4)7@`V":X&QAAN"XH)[EX,V%X&11(N``4"7@!6"6X&`!H.$#4)K@`E"5X,"@
MGN7L+8;@9&$@X`Q@)N`&4)7@`V":X&1AAN#(H)[E;$$@X`)`).#B787@!&"6
MX&(AH.$#0)K@``"4X-"@GN5L02+@!4`DX`1`D.`#`)K@Y6V&X-B@GN5L`8#@
M9<$BX`;`+.#F383@#`"0X&9AH.$#P)K@`B"<X."@GN5EP2;@!,`LX`S`DN`#
M()K@Y`V`X.B@GN5E(8+@9%$FX`!0)>#@S8S@!2"2X&`!H.$#4)K@!E"5X/B@
MGN7P8)[E9.$@X`S@+N#L+8+@#N"5X.)=CN`#8);@;.$@X&1!AN`"X"[@#N"4
MX&(AH.$#0)K@`$"4X!AAG>5L`2+@!0`@X.7MCN```)3@`V"6X.Y-@.!LP8;@
M90$BX"!AG>4.`"#@``"<X&[AH.$#8);@`B"6X&7!+N`H89WE!,`LX.0-@.`,
MP)+@`R"6X&4A@N`P89WEX%V,X&3!+N``P"S@#,"2X&`!H.$#8);@Y2V,X`[@
MEN!DP2#@.&&=Y07`+.`,P)[@`^"6X&3ACN!`89WE94$@X`)`).#BS8S@!.">
MX&(AH.$#8);@``"6X&5!(N!(89WE#$`DX.SMCN!0H9WE!$"0X`,`EN#L-9_E
M;&$BX&4!@.`.8";@;E&@X>Y-A.`&8)#@;.&%X0,`FN`"`)#@6*&=Y>0MAN`$
MX`[@;&$%X`;@CN$.X)#@`Z":X&0!A>%D807@;,&*X`(``.!@H9WE!@"`X>+M
MCN`,`)#@8B&@X0/`FN`%P)S@9%&"X61A`N!HH9WE#E`%X`90A>'N#8#@#%"5
MX`.@FN!NP8+A;F$"X&1!BN``P`S@<*&=Y0;`C.'@787@!$"<X&`!H.$#P)K@
M`L"<X.4MA.!N08#A;F$`X'BAG>4%0`3@!D"$X0Q`E.`#H)K@9<&`X65A`.!N
MX8K@`L`,X("AG>4&P(SAXDV$X`[@G.!B(:#A`\":X`#`G.#D#8[@9>&"X65A
M`N"(H9WE!.`.X`;@CN$,X)[@`Z":X&3!@N%D80+@95&*X`#`#."0H9WE!L",
MX>#MCN`%4)S@8`&@X0/`FN`"P)S@[BV%X&11@.%D80#@F*&=Y0Y0!>`&4(7A
M#%"5X`.@FN!NP8#A;F$`X&1!BN`"P`S@H*&=Y0;`C.'B787@!$"<X&(AH.$#
MP)K@`,"<X.4-A.!N08+A;F$"X*BAG>4%0`3@!D"$X0Q`E.`#H)K@9<&"X65A
M`N!NX8K@`,`,X+"AG>4&P(SAX$V$X`[@G.!@`:#A`\":X`+`G.#D+8[@9>&`
MX65A`."XH9WE!.`.X`;@CN$,X)[@`Z":X&3!@.%D80#@95&*X`+`#.#`H9WE
M!L",X>+MCN`%4)S@8B&@X0/`FN``P)S@[@V%X&11@N'(H9WE9&$"X`Y0!>`&
M4(7A#%"5X`.@FN!NP8+A;F$"X&1!BN``P`S@T*&=Y0;`C.'@787@!$"<X&`!
MH.$#P)K@`&"@XP+`G.#E+83@;D&`X05`!.`$8('E#&"!Y11@@>4<8('E;F$`
MX-BAG>4&0(3A#$"4X&7!@.$#H)K@96$`X`+`#.!NX8K@!L",X>"AG>7B383@
M#L"<X&(AH.'D[8S@`Z":X&7!@N%E80+@``":X`3`#.#HH9WE!L",X0#`G.`#
MH)K@9`&"X>@RG^5D80+@95&*X`X``.#PH9WE!@"`X>[-C.`%`)#@;N&@X0-0
MFN`"4)7@^&&=Y60A+N`,("+@[`V`X`(@E>`#8);@X%V"X&1!AN!L(2[@`&*=
MY0`@(N`"()3@8`&@X0-`EN`.0)3@"&*=Y6SA(.`%X"[@#N"4X`-`EN#E+8+@
M$&*=Y6Q!A.!EP2#@`L`LX.+MCN`,P)3@8B&@X0-`EN``0)3@&&*=Y64!(N`.
M`"#@[LV,X```E.`#0);@94&$X"!BG>7L78#@;@$BX`P`(.```)3@;,&@X0-`
MEN`"0)3@*&*=Y6XA+.`%("+@Y0V`X`(@E.`#8);@X$V"X&[AAN!E(2S@,&*=
MY0`@(N`"()[@8`&@X0/@EN`,X)[@.&*=Y67!(.`$P"S@Y"V"X`S`GN`#X);@
M9>&.X$!BG>7B78S@9,$@X`+`+.`,P)[@8B&@X0/@EN``X)[@2&*=Y60!(N`%
M`"#@Y<V,X```GN`#X);@9.&.X%!BG>7L38#@90$BX`P`(.```)[@;,&@X0/@
MEN`"X)[@6&*=Y64A+.`$("+@Y`V`X`(@GN`#X);@9>&.X&!BG>7@78+@9"$L
MX``@(N`"()[@8`&@X0/@EN`,X)[@:&*=Y63!(.`%P"S@Y2V"X`S`GN`#X);@
M9.&.X'!BG>7B38S@9<$@X`+`+.`,P)[@8B&@X0/@EN``X)[@>&*=Y64!(N`$
M`"#@``">X`/@EN#DS8S@9>&.X&1A(N"`4IWE#&`FX.P-@.`&X)[@;,&@X0-0
ME>`"()7@9&$LX(A2G>4`8";@!B"2X`,PE>#@[8[@8)&)X`@PD^!@`2S@#@`@
MX&0Q@^``,)/@[BV"X.(]@^!N<8?@"R"2X"``D>48D('E$'"!Y0`P@>4((('E
M4""?Y3@PG^4"((_@`,"<X`!@H.,@P('E)&"!Y0,PDN<`()/EE#*=Y0(@,^``
M,*#C`0``&J??C>+PC[WHC//_Z_QE```<`0``F7F"6J'KV6[<O!N/UL%BRMA9
M``!P0"WI@`"@XW_S_^M04(_BT$#%X0`@H./P0,#A2%"/XM!`Q>%X((#E^$#`
MX4!0C^+00,7A\$'`X3Q0C^+00,7A^$'`X3A0C^+00,7A\$+`X0!`H.,`4*#C
M^$+`X?!#P.%P@+WH`2-%9P````")J\WO`````/[<NI@`````=E0R$`````#P
MX=+#`````/!'+>DH,)#E`F"@X8;!@^`L()#E`P!<X0`PH.,"(-/@`%"@X3`@
MD.4!0*#A-!"0Y<8/H.$!```J`2"2X@`0H>(L,(7EICZ@X8`Q@^$",)/@H!ZA
MX'@`E>4X@(7B``!0XRC`A>4P,(7E-!"%Y18``!H_`%;C)0``VD!@1N(FDZ#A
M`7")X@=SA.`$$*#A0""@XP@`H.$8\__K0$"$X@4`H.&2_/_K!P!4X?;__QH)
MG6G@"6.&X`8@H.$'$*#A"`"@X0WS_^MX8(7E\(>]Z$!P8.(&`%?A!G"@H0``
MB.`'(*#A!!"@X03S_^MX,)7E`S"'X$``4^-X,(7E\(>]&`4`H.$'8$;@!T"$
MX'C\_^O7___J!'"@X>;__^KP02WI*#"1Y0%`H.%C*"/@,!"1Y2(DH.'_+,+C
M8W0BX&$H(>"C,:#A(B2@X3\P`^+_+,+C860BX`$@@^(X@(3B?Q#@XS@`4N,`
M4*#A`Q#(YP(`B.`\``#:0"!BX@`0H..U\O_K!`"@X5K\_^L(`*#A.""@XP`0
MH..O\O_K!`"@X7!@A.5T<(3E4OS_ZP,PU.4`,,7ELC#4X0$PQ>4`,)3E!`"@
MX2,TH.$",,7E`#"4Y0,PQ>4+,-3E!##%Y;HPU.$%,,7E"#"4Y2,TH.$&,,7E
M"#"4Y0<PQ>43,-3E"##%Y;(QU.$),,7E$#"4Y2,TH.$*,,7E$#"4Y0LPQ>4;
M,-3E###%Y;HQU.$-,,7E&#"4Y2,TH.$.,,7E&#"4Y0\PQ>4C,-3E$##%Y;(R
MU.$1,,7E(#"4Y2,TH.$2,,7E(#"4Y1,PQ>7P0;WHBO+_ZC@@8N(`$*#C>/+_
MZ\?__^H````````````````/"N#C'_!`X@@PG^4#,(_@`#"3Y<[R_^J@5P``
M"$`MZ0B`O>@!``(`/0```$`````+````0````!````!`````)@```$`````U
M````0`````,```!`````!@```$`````4````0`````X```!`````#0```$``
M```E````0````!(```!`````*````$`````"````0````!@```!`````"0``
M`$`````*````0```````````````)7,O)7,````O<')O8R]S96QF+V5X90``
M1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"
M3T]4`````"]P<F]C+R5I+R5S`&5X90`N````4$%27U1%35``````4$%27U!2
M3T=.04U%`````#H````E<R5S)7,``"\```!015),-4Q)0@````!015),3$E"
M`%!%4DPU3U!4`````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%7
M3D5$`%!!4E]#3$5!3@```%!!4E]$14)51P```%!!4E]#04-(10```%!!4E]'
M3$]"04Q?1$5"54<`````4$%27T=,3T)!3%]435!$25(```!005)?5$U01$E2
M``!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@`````Q````3$1?
M3$E"4D%265]0051(`%-94U1%30``)3`R>``````E<R5S)7,E<P````!P87(M
M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F
M86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E
M<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@
M;W!E<F%T:6]N*0H``%!!5$@`````<&%R;``````N<&%R`````"5S)7-C86-H
M92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P`````8
M````<&5R;``````P````4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP-3@`
M``!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@8W)E
M871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D
M("AE<G)N;STE:2D*`````"UE```M+0``55-%4@````!54T523D%-10````!4
M14U01$E2`%1-4``O=&UP`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@
M+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O
M;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&
M24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD
M4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`]
M(#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:
M25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC
M"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0[
M"FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE
M+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D
M<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@
M/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C
M:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@
M<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S
M("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*
M;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A
M8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I
M;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL
M93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE
M*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?
M=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_
M(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M
M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY
M("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8
M)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3
M549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE
M(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W
M:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF
M(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q
M"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO
M<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F
M:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T
M<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L
M96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ
M4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0[
M"F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!
M4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@
M+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^
M("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L
M:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I
M+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D
M<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM0
M05)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S
M+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)
M1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A
M=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE
M("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E
M<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`]
M(&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*
M;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@
M:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O
M=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@
M7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H
M(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(
M12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!
M3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'
M24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E
M96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E
M860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]
M('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O
M9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@
M)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,
M15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@
M7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A
M9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR
M96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L
M("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN
M9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M
M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D
M8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN
M*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@
M+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E
M7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO
M9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@
M)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U
M;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@
M/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@
M<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A
M8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E
M<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R
M+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I
M;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2([
M"B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F
M:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N
M86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F
M?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G
M/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE
M;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@
M9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I
M.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I
M<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4[
M"G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI
M<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M
M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI
M('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U
M;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*
M9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N
M92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@
M1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)
M0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@
M("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L
M("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM0
M05)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C
M=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E
M<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]
M('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN
M<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H
M0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'
M5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@
M>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI
M;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=
M*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O
M7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B
M.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R
M.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D
M,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@
M)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2![
M"B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F
M:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R
M(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D
M,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q
M?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q
M=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S
M($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE
M>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D
M;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI:
M:7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!
M4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F
M:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL
M92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]
M($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L
M92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I
M92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@
M)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP
M+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD
M+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ
M72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@
M;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A
M<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@
M-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B
M=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D
M;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE
M.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ
M3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL
M92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P
M.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T
M:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T
M:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&
M2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@
M+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D
M,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I
M=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E
M<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`]
M(&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G
M*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD
M7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\
M+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE
M<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V
M86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB
M7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W
M<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*
M;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@
M*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@
M>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@
M)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO
M;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#
M86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T
M.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D
M:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE
M9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A
M<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO
M=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I
M;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF
M("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L
M<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@
M)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N
M=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I
M<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D
M14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L
M*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<
M)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L
M"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O
M)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N
M86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*
M;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U
M="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF
M("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@
M<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F
M:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C
M86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS
M965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@
M,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE
M7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I
M>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M
M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L
M"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T
M:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B10
M05)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG
M('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X
M:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?
M<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C
M:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O
M;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I
M(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP
M.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII
M<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N
M86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O
M<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ
M6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#
M86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`[
M"F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[
M4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF
M;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF
M("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M
M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U[
M"EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH
M6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?
M;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E
M>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M
M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG
M("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D
M9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M
M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE
M>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M
M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I
M(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#
M86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5
M<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=
M(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O
M=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N
M86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM
M>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D
M8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE
M<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&
M:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@
M;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@
M>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN
M=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U
M:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*
M<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I
M<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M
M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U
M:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&
M:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I
M<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C
M:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@
M0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E
M(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII
M<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A
M<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)
M3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E
M=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E
M='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H
M(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#
M.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T
M:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY
M("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F
M:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@
M>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F
M:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD
M=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=3
M65-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R
M+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P
M-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C
M86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B
M/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G
M;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G
M:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%
M7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68[
M"G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@
M97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?
M;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE
M7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD
M8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*
M?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@
M/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@
M+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@
M,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R
M7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-
M4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O
M;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M
M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M
M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W
M)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L
M;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z
M("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E
M.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M
M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA
M;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[
M4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*
M)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E
M>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M
M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[
M7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I
M;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E
M;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@[
M"GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@
M+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS
M<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT
M(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!
M4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R
M;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5]
M(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y
M<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O
M9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA
M;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\
M?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D
M<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM
M?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W
M9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D
M*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P
M<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D
M<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64[
M"GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)
M6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)
M5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@
M1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D
M7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*
M)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI
M<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-
M4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*
M<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@
M(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I
M;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L
M(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV
M;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V
M96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU
M;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A
M<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP
M="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU
M;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H
M)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I
M9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H
M)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*
M9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`<&5R
M;'AS:2YC`````$-!0TA%```]````0`````L```!`````$````$`````F````
M0````#4```!``````P```$`````&````0````!0```!`````#@```$`````-
M````0````"4```!`````$@```$`````H````0`````(```!`````&````$``
M```)````0`````H```!```````````````#4C/]_`0``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````?!@``!08```!````"@,```$````:`P```0``
M`"0#```,````@!$```T```!L2```&0```,"=```;````!````!H```#$G0``
M'`````0```#U_O]OK`$```4````$"0``!@```)0"```*````G`0```L````0
M````%0`````````#````T)X```(```#@`0``%````!$````7````H`\``!$`
M``#0#@``$@```-`````3````"````!X````(````^___;P$```C^__]O<`X`
M`/___V\"````\/__;Z`-``#Z__]O#@``````````````````````````````
M``````````````````````````#(G0````````````",$0``C!$``(P1``",
M$0``C!$``(P1``",$0``C!$``(P1``",$0``C!$``(P1``",$0``C!$``(P1
M``",$0``C!$``(P1``",$0``C!$``(P1``",$0``C!$``(P1``",$0``C!$`
M`(P1``",$0``C!$``(P1``",$0``C!$``(P1``",$0``C!$``(P1``",$0``
MC!$``(P1``",$0``C!$``(P1``",$0``C!$``(P1``",$0``C!$``(P1``",
M$0``C!$``(P1``",$0``C!$``(P1``",$0``C!$``(P1``",$0``C!$``(P1
M````````````````````````````````````````````````````````````
M``````!P%`````````2@```*4$%2+G!M"@`````H3```9$D````````D2@``
M*$H``!Q,``!L20``)$P````````(3```$$P````````P3```1T-#.B`H1&5B
M:6%N(#$R+C,N,"TT*2`Q,BXS+C``02H```!A96%B:0`!(`````4U5$4`!@0(
M`0D!$@03`10!%0$7`Q@!&0$:`@`N<VAS=')T86(`+FEN=&5R<``N;F]T92YG
M;G4N8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N
M9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N
M<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"Y!4DTN97AI9'@`
M+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG
M;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N05)-+F%T=')I8G5T97,`````````
M````````````````````````````````````````````````"P````$````"
M````5`$``%0!```3```````````````!`````````!,````'`````@```&@!
M``!H`0``)```````````````!``````````F````!P````(```",`0``C`$`
M`"````````````````0`````````-````/;__V\"````K`$``*P!``#H````
M!0`````````$````!````#X````+`````@```)0"``"4`@``<`8```8````#
M````!````!````!&`````P````(````$"0``!`D``)P$``````````````$`
M````````3@```/___V\"````H`T``*`-``#.````!0`````````"`````@``
M`%L```#^__]O`@```'`.``!P#@``8`````8````"````!`````````!J````
M"0````(```#0#@``T`X``-`````%``````````0````(````<P````D```!"
M````H`\``*`/``#@`0``!0```!4````$````"````'P````!````!@```(`1
M``"`$0``#```````````````!`````````!W`````0````8```",$0``C!$`
M`.0"``````````````0````$````@@````$````&````<!0``'`4``#\,P``
M```````````0`````````(@````!````!@```&Q(``!L2```"```````````
M````!`````````".`````0````(```!T2```=$@``-!!``````````````0`
M````````E@````$``'""````1(H``$2*```(````#0`````````$````````
M`*$````!`````@```$R*``!,B@``!```````````````!`````````"K````
M#@````,```#`G0``P(T```0```````````````0````$````MP````\````#
M````Q)T``,2-```$```````````````$````!````,,````&`````P```,B=
M``#(C0``"`$```8`````````!`````@```#,`````0````,```#0G@``T(X`
M`#`!``````````````0````$````T0````$````#`````*````"0``!(````
M```````````$`````````-<````(`````P```$B@``!(D```%```````````
M````!`````````#<`````0```#``````````2)```!X```````````````$`
M```!````Y0````,``'```````````&:0```K```````````````!````````
I``$````#``````````````"1D```]0```````````````0``````````
